:py:mod:`icclim._core.model.netcdf_version`
===========================================

.. py:module:: icclim._core.model.netcdf_version

.. autoapi-nested-parse::

   Module containing the NetCDF version model and its registry.



Module Contents
---------------

.. py:class:: NetcdfVersion


   Class representing a NetCDF version.

   .. attribute:: name

      The name of the NetCDF version.

      :type: {'NETCDF4', 'NETCDF4_CLASSIC', 'NETCDF3_64BIT', 'NETCDF3_CLASSIC'}


.. py:class:: NetcdfVersionRegistry




   Registry of NetCDF versions.
